@@ -93,7 +93,10 @@ typedef  Z_longword         *Z_longwordptr;
     #elif PERL_DARWIN
         #define boolean bool
     #else
-        typedef enum { false = FALSE, true = TRUE } boolean;
+	typedef int boolean;
+	#ifndef I_STDBOOL
+	    enum { false, true };
+	#endif
     #endif
 #endif
 
@@ -120,11 +123,12 @@ typedef  Z_longword         *Z_longwordptr;
 /*****************************************************************************/
 
 /*****************************************************************************/
-/*  VERSION:  5.6                                                            */
+/*  VERSION:  5.7                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
+/*    Version 5.7   17.05.12  Changed boolean data type.                     */
 /*    Version 5.6   27.07.09  Made it MacOS X compatible.                    */
 /*    Version 5.5   03.10.04  Added compiler directives for C++.             */
 /*    Version 5.4   08.09.02  Added conditional changes for MacOS/MacPerl.   */
@@ -144,14 +148,14 @@ typedef  Z_longword         *Z_longwordptr;
 /*****************************************************************************/
 /*                                                                           */
 /*    Steffen Beyer                                                          */
-/*    mailto:sb@engelschall.com                                              */
+/*    mailto:STBEY@cpan.org                                                  */
 /*    http://www.engelschall.com/u/sb/download/                              */
 /*                                                                           */
 /*****************************************************************************/
 /*  COPYRIGHT:                                                               */
 /*****************************************************************************/
 /*                                                                           */
-/*    Copyright (c) 1995 - 2009 by Steffen Beyer.                            */
+/*    Copyright (c) 1995 - 2013 by Steffen Beyer.                            */
 /*    All rights reserved.                                                   */
 /*                                                                           */
 /*****************************************************************************/
